@@ -5,11 +5,12 @@ use strict;
 use warnings;
 
 use AnyEvent;
+use Data::Dumper;
 
-our $VERSION = '0.13_001';
+our $VERSION = '0.01';
 
 require XSLoader;
-XSLoader::load('AnyEvent::YACurl', '0.13_001');
+XSLoader::load('AnyEvent::YACurl', $VERSION);
 
 require constant;
 my %constants= %{_get_known_constants()};
@@ -79,7 +80,7 @@ AnyEvent::YACurl - Yet Another cURL binding for AnyEvent
     use AnyEvent;
     use AnyEvent::YACurl ':constants';
 
-    my $client = AnyEvent::YACurl->new({});
+    my $client = AnyEvent::YACurl->new;
     my $condvar = AnyEvent->condvar;
     my $return_data = '';
     $client->request($condvar, {
@@ -108,11 +109,6 @@ This module provides bindings to cURL, integrated into AnyEvent.
 Returns a new C<AnyEvent::YACurl> object. This is essentially a binding over cURL's
 L<"multi" interface|https://curl.haxx.se/libcurl/c/libcurl-multi.html>.
 
-Its first and only argument is a required hashref containing options to control behavior, such as
-C<CURLMOPT_MAX_TOTAL_CONNECTIONS>. Refer to the actual
-L<cURL documentation|https://curl.haxx.se/libcurl/c/curl_multi_setopt.html> to find out about
-other options to pass.
-
 =item C<request>
 
 Performs a request using the client instantiated via C<new>. Takes a callback and a hashref of
@@ -167,7 +163,7 @@ Tom van der Woerdt <tvdw@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Tom van der Woerdt.
+This software is copyright (c) 2018 by Tom van der Woerdt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
